.. confect documentation master file, created by
   sphinx-quickstart on Wed Mar  2 11:50:23 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Labrea
------

Labrea is a framework for declarative, functional, modular dataset definitions. Get started with the
:doc:`Installation Instructions <installation>`.


.. toctree::
   :hidden:
   :maxdepth: 1
   :caption: References

   Installation <installation>
   Usage <usage>
   API <api>
   Changelog <changelog>
   Contributing <contributing>


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
